==> seqan3_3.0.2+ds.orig.tar.xz: seqan3-3.0.2-Source/CODE_OF_CONDUCT.md <==
# Code of Conduct {#about_code_of_conduct}

The SeqAn project adheres to the [Berlin Code of Conduct](https://berlincodeofconduct.org/). From the code of conduct:

> A primary goal of all the conferences and user groups that refer to this Code of Conduct is to be inclusive to the largest number of contributors, with the most varied and diverse backgrounds possible. As such, we are committed to providing a friendly, safe and welcoming environment for all, regardless of gender, sexual orientation, ability, ethnicity, socioeconomic status and religion (or lack thereof).

> A supplemental goal of this Code of Conduct is to increase open [source/culture/tech] citizenship by encouraging participants to recognize and strengthen the relationships between our actions and their effects on our community.

Please have a look at the full text here: https://berlincodeofconduct.org/

Many SeqAn core team members and contributors are employees and/or (PhD) students of Freie Universität Berlin and
are thus also bound by the
[Academic Honour Code](https://www.fu-berlin.de/forschung/service/Ehrenkodex-ab292002.pdf).

# Scope

This Code of Conduct applies both within project spaces and in public spaces when an individual is representing the
project or its community. In particular, it applies to:

  * Communication on GitHub, including issues, pull-requests and commit messages;
  * the `seqan-dev` and `seqan-team` mailing lists;
  * the Gitter chat rooms;
  * social media accounts of SeqAn;
  * SeqAn-related meetings in real life.

# Enforcement

If you observe a violation of this Code of Conduct, you can do one of the following, depending on the severity of
the violation and your own capacity to deal with the offending person:

  * Try to resolve the matter immediately with the person by referring to this Code of Conduct.
  * Raise the issue at a weekly meeting of the core team or by contacting a member of the
    [core team](https://github.com/orgs/seqan/teams/core). The core team is obligated to maintain confidentiality with
    regard to the reporter of an incident.
  * If the problem is with a person on the core team, you can contact [Lutz Prechelt](mailto:<prechelt@inf.fu-berlin.de>).
    He is a professor at Freie Universität Berlin and not directly involved with the SeqAn project. He has agreed to
    help find solutions or redirect to other helpful entities if cases are brought to him.
  * Employees and students of Freie Universität Berlin can also contact one of the
    [bodies representing specific interests](https://www.fu-berlin.de/en/einrichtungen/interessenvertretungen/index.html).

None of the above suggestions limit your possibilities to pursue other professional/legal council or action.

*Note to SeqAn-Team: This code of conduct should be re-evaluated before the end of 2022. In particular Lutz Prechelt's
agreement to serve as contact person is contingent on renewal.*

==> seqan3_3.2.0+ds.orig.tar.xz: seqan3-3.2.0-Source/CODE_OF_CONDUCT.md <==
# Code of Conduct {#about_code_of_conduct}

The SeqAn project adheres to the [Berlin Code of Conduct](https://berlincodeofconduct.org/). From the code of conduct:

> A primary goal of all the conferences and user groups that refer to this Code of Conduct is to be inclusive to the largest number of contributors, with the most varied and diverse backgrounds possible. As such, we are committed to providing a friendly, safe and welcoming environment for all, regardless of gender, sexual orientation, ability, ethnicity, socioeconomic status and religion (or lack thereof).

> A supplemental goal of this Code of Conduct is to increase open [source/culture/tech] citizenship by encouraging participants to recognize and strengthen the relationships between our actions and their effects on our community.

Please have a look at the full text here: https://berlincodeofconduct.org/

Many SeqAn core team members and contributors are employees and/or (PhD) students of Freie Universität Berlin and
are thus also bound by the
[Academic Honour Code](https://www.fu-berlin.de/service/zuvdocs/amtsblatt/2002/ab292002.pdf).

# Scope

This Code of Conduct applies both within project spaces and in public spaces when an individual is representing the
project or its community. In particular, it applies to:

  * Communication on GitHub, including issues, pull-requests and commit messages;
  * the `seqan-dev` and `seqan-team` mailing lists;
  * the Gitter chat rooms;
  * social media accounts of SeqAn;
  * SeqAn-related meetings in real life.

# Enforcement

If you observe a violation of this Code of Conduct, you can do one of the following, depending on the severity of
the violation and your own capacity to deal with the offending person:

  * Try to resolve the matter immediately with the person by referring to this Code of Conduct.
  * Raise the issue at a weekly meeting of the core team or by contacting a member of the
    [core team](https://github.com/orgs/seqan/teams/core). The core team is obligated to maintain confidentiality with
    regard to the reporter of an incident.
  * If the problem is with a person on the core team, you can contact [Lutz Prechelt](mailto:<prechelt@inf.fu-berlin.de>).
    He is a professor at Freie Universität Berlin and not directly involved with the SeqAn project. He has agreed to
    help find solutions or redirect to other helpful entities if cases are brought to him.
  * Employees and students of Freie Universität Berlin can also contact one of the
    [bodies representing specific interests](https://www.fu-berlin.de/en/einrichtungen/interessenvertretungen/index.html).

None of the above suggestions limit your possibilities to pursue other professional/legal council or action.

*Note to SeqAn-Team: This code of conduct should be re-evaluated before the end of 2022. In particular Lutz Prechelt's
agreement to serve as contact person is contingent on renewal.*
